# `unfolded.data-sdk`

Python package for interfacing with [Unfolded](https://unfolded.ai)'s Data SDK.

For more documentation, refer to the [documentation website](https://docs.unfolded.ai/data-sdk).
